@@ -12,6 +12,7 @@
 
 #include "adw-animation-util.h"
 #include "adw-gizmo-private.h"
+#include "adw-macros-private.h"
 #include "adw-shadow-helper-private.h"
 #include "adw-spring-animation.h"
 #include "adw-swipeable.h"
@@ -72,7 +73,7 @@
  *
  * The `AdwFlap` implementation of the [iface@Gtk.Buildable] interface supports
  * setting the flap child by specifying “flap” as the “type” attribute of a
- * `<child>` element, and separator by specifying “separator”. Specifying
+ * <child> element, and separator by specifying “separator”. Specifying
  * “content” child type or omitting it results in setting the content child.
  *
  * ## CSS nodes
@@ -80,7 +81,7 @@
  * `AdwFlap` has a single CSS node with name `flap`. The node will get the style
  * classes `.folded` when it is folded, and `.unfolded` when it's not.
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 
 /**
@@ -93,7 +94,7 @@
  *
  * Describes the possible folding behavior of a [class@Flap] widget.
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 
 /**
@@ -112,7 +113,9 @@
  * [class@Flap] widget, as well as which areas can be swiped via
  * [property@Flap:swipe-to-open] and [property@Flap:swipe-to-close].
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * New values may be added to this enum over time.
+ *
+ * Since: 1.0
  */
 
 typedef struct {
@@ -328,7 +331,7 @@ animate_reveal (AdwFlap *self,
                                        self->reveal_progress);
   adw_spring_animation_set_value_to (ADW_SPRING_ANIMATION (self->reveal_animation), to);
 
-  if (!G_APPROX_VALUE (self->reveal_progress, to, DBL_EPSILON))
+  if (!G_APPROX_VALUE (self->reveal_progress, to, FLT_EPSILON))
     adw_spring_animation_set_initial_velocity (ADW_SPRING_ANIMATION (self->reveal_animation),
                                                velocity / adw_swipeable_get_distance (ADW_SWIPEABLE (self)));
   else
@@ -360,6 +363,8 @@ static void
 set_folded (AdwFlap  *self,
             gboolean  folded)
 {
+  GtkStyleContext *context;
+
   folded = !!folded;
 
   if (self->folded == folded)
@@ -381,12 +386,13 @@ set_folded (AdwFlap  *self,
   if (!self->locked)
     set_reveal_flap (self, !self->folded, 0);
 
+  context = gtk_widget_get_style_context (GTK_WIDGET (self));
   if (folded) {
-    gtk_widget_add_css_class (GTK_WIDGET (self), "folded");
-    gtk_widget_remove_css_class (GTK_WIDGET (self), "unfolded");
+    gtk_style_context_add_class (context, "folded");
+    gtk_style_context_remove_class (context, "unfolded");
   } else {
-    gtk_widget_remove_css_class (GTK_WIDGET (self), "folded");
-    gtk_widget_add_css_class (GTK_WIDGET (self), "unfolded");
+    gtk_style_context_remove_class (context, "folded");
+    gtk_style_context_add_class (context, "unfolded");
   }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLDED]);
@@ -406,14 +412,10 @@ static void
 begin_swipe_cb (AdwSwipeTracker *tracker,
                 AdwFlap         *self)
 {
-  if ((G_APPROX_VALUE (self->reveal_progress, 0, DBL_EPSILON) ||
-       self->reveal_progress < 0) &&
-      !self->swipe_to_open)
+  if (self->reveal_progress <= 0 && !self->swipe_to_open)
     return;
 
-  if ((G_APPROX_VALUE (self->reveal_progress, 1, DBL_EPSILON) ||
-       self->reveal_progress > 1) &&
-      !self->swipe_to_close)
+  if (self->reveal_progress >= 1 && !self->swipe_to_close)
     return;
 
   adw_animation_pause (self->reveal_animation);
@@ -689,10 +691,9 @@ interpolate_reveal (AdwFlap  *self,
                     int      *content_size,
                     int      *separator_size)
 {
-  
-  if (G_APPROX_VALUE (self->reveal_progress, 0, DBL_EPSILON) || self->reveal_progress < 0) {
+  if (self->reveal_progress <= 0) {
     compute_sizes (self, width, height, folded, FALSE, flap_size, content_size, separator_size);
-  } else if (G_APPROX_VALUE (self->reveal_progress, 1, DBL_EPSILON) || self->reveal_progress > 1) {
+  } else if (self->reveal_progress >= 1) {
     compute_sizes (self, width, height, folded, TRUE, flap_size, content_size, separator_size);
   } else {
     int flap_revealed, content_revealed, separator_revealed;
@@ -721,9 +722,9 @@ interpolate_fold (AdwFlap *self,
                   int     *content_size,
                   int     *separator_size)
 {
-  if (G_APPROX_VALUE (self->fold_progress, 0, DBL_EPSILON) || self->fold_progress < 0) {
+  if (self->fold_progress <= 0) {
     interpolate_reveal (self, width, height, FALSE, flap_size, content_size, separator_size);
-  } else if (G_APPROX_VALUE (self->fold_progress, 1, DBL_EPSILON) || self->fold_progress > 1) {
+  } else if (self->fold_progress >= 1) {
     interpolate_reveal (self, width, height, TRUE, flap_size, content_size, separator_size);
   } else {
     int flap_folded, content_folded, separator_folded;
@@ -987,7 +988,7 @@ adw_flap_measure (GtkWidget      *widget,
     }
 
     min = MAX (content_min + (int) round ((flap_min + separator_min) * min_progress), flap_min);
-    nat = MAX (content_nat + (int) round ((flap_nat + separator_nat) * nat_progress), flap_nat);
+    nat = MAX (content_nat + (int) round ((flap_nat + separator_min) * nat_progress), flap_nat);
   } else {
     min = MAX (MAX (content_min, flap_min), separator_min);
     nat = MAX (MAX (content_nat, flap_nat), separator_nat);
@@ -1229,9 +1230,10 @@ adw_flap_dispose (GObject *object)
 {
   AdwFlap *self = ADW_FLAP (object);
 
-  g_clear_pointer (&self->flap.widget, gtk_widget_unparent);
-  g_clear_pointer (&self->separator.widget, gtk_widget_unparent);
-  g_clear_pointer (&self->content.widget, gtk_widget_unparent);
+  adw_flap_set_flap (self, NULL);
+  adw_flap_set_separator (self, NULL);
+  adw_flap_set_content (self, NULL);
+
   g_clear_pointer (&self->shield, gtk_widget_unparent);
 
   g_clear_object (&self->shadow_helper);
@@ -1266,14 +1268,17 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * The content widget.
    *
-   * It's always displayed when unfolded, and partially visible when folded.
+   * It's always displayed when unfolded, and partially visible
+   * when folded.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_CONTENT] =
-    g_param_spec_object ("content", NULL, NULL,
+    g_param_spec_object ("content",
+                         "Content",
+                         "The content widget",
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:flap: (attributes org.gtk.Property.get=adw_flap_get_flap org.gtk.Property.set=adw_flap_set_flap)
@@ -1282,12 +1287,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * It's only visible when [property@Flap:reveal-progress] is greater than 0.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_FLAP] =
-    g_param_spec_object ("flap", NULL, NULL,
+    g_param_spec_object ("flap",
+                         "Flap",
+                         "The flap widget",
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:separator: (attributes org.gtk.Property.get=adw_flap_get_separator org.gtk.Property.set=adw_flap_set_separator)
@@ -1298,12 +1305,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * When exactly it's visible depends on the [property@Flap:transition-type]
    * value.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_SEPARATOR] =
-    g_param_spec_object ("separator", NULL, NULL,
+    g_param_spec_object ("separator",
+                         "Separator",
+                         "The separator widget",
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:flap-position: (attributes org.gtk.Property.get=adw_flap_get_flap_position org.gtk.Property.set=adw_flap_set_flap_position)
@@ -1313,25 +1322,29 @@ adw_flap_class_init (AdwFlapClass *klass)
    * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
    * if `GTK_PACK_END`, it's displayed after the content.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_FLAP_POSITION] =
-    g_param_spec_enum ("flap-position", NULL, NULL,
+    g_param_spec_enum ("flap-position",
+                       "Flap Position",
+                       "The flap position",
                        GTK_TYPE_PACK_TYPE,
                        GTK_PACK_START,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:reveal-flap: (attributes org.gtk.Property.get=adw_flap_get_reveal_flap org.gtk.Property.set=adw_flap_set_reveal_flap)
    *
    * Whether the flap widget is revealed.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_REVEAL_FLAP] =
-    g_param_spec_boolean ("reveal-flap", NULL, NULL,
+    g_param_spec_boolean ("reveal-flap",
+                          "Reveal Flap",
+                          "Whether the flap is revealed",
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:reveal-params: (attributes org.gtk.Property.get=adw_flap_get_reveal_params org.gtk.Property.set=adw_flap_set_reveal_params)
@@ -1344,12 +1357,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * adw_spring_params_new (1, 0.5, 500)
    * ```
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_REVEAL_PARAMS] =
-    g_param_spec_boxed ("reveal-params", NULL, NULL,
+    g_param_spec_boxed ("reveal-params",
+                        "Reveal Parameters",
+                        "The reveal animation spring parameters",
                         ADW_TYPE_SPRING_PARAMS,
-                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:reveal-progress: (attributes org.gtk.Property.get=adw_flap_get_reveal_progress)
@@ -1360,25 +1375,29 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * See [property@Flap:reveal-flap].
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_REVEAL_PROGRESS] =
-    g_param_spec_double ("reveal-progress", NULL, NULL,
+    g_param_spec_double ("reveal-progress",
+                          "Reveal Progress",
+                          "The current reveal transition progress",
                           0.0, 1.0, 1.0,
-                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
+                          G_PARAM_READABLE);
 
   /**
-   * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy org.gtk.Property.set=adw_flap_set_fold_policy)
+   * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy)
    *
    * The fold policy for the flap.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_FOLD_POLICY] =
-    g_param_spec_enum ("fold-policy", NULL, NULL,
+    g_param_spec_enum ("fold-policy",
+                       "Fold Policy",
+                       "The fold policy for the flap",
                        ADW_TYPE_FLAP_FOLD_POLICY,
                        ADW_FLAP_FOLD_POLICY_AUTO,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:fold-threshold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_threshold_policy org.gtk.Property.set=adw_flap_set_fold_threshold_policy)
@@ -1392,26 +1411,30 @@ adw_flap_class_init (AdwFlapClass *klass)
    * This can be useful if you have a long ellipsizing label and want to let it
    * ellipsize instead of immediately folding.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_FOLD_THRESHOLD_POLICY] =
-    g_param_spec_enum ("fold-threshold-policy", NULL, NULL,
+    g_param_spec_enum ("fold-threshold-policy",
+                       "Fold Threshold Policy",
+                       "Determines when the flap will fold",
                        ADW_TYPE_FOLD_THRESHOLD_POLICY,
                        ADW_FOLD_THRESHOLD_POLICY_MINIMUM,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:fold-duration: (attributes org.gtk.Property.get=adw_flap_get_fold_duration org.gtk.Property.set=adw_flap_set_fold_duration)
    *
    * The fold transition animation duration, in milliseconds.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_FOLD_DURATION] =
-    g_param_spec_uint ("fold-duration", NULL, NULL,
+    g_param_spec_uint ("fold-duration",
+                       "Fold Duration",
+                       "The fold transition animation duration, in milliseconds",
                        0, G_MAXINT,
                        250,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:folded: (attributes org.gtk.Property.get=adw_flap_get_folded)
@@ -1420,12 +1443,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * See [property@Flap:fold-policy].
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_FOLDED] =
-    g_param_spec_boolean ("folded", NULL, NULL,
+    g_param_spec_boolean ("folded",
+                          "Folded",
+                          "Whether the flap is currently folded",
                           FALSE,
-                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
+                          G_PARAM_READABLE);
 
   /**
    * AdwFlap:locked: (attributes org.gtk.Property.get=adw_flap_get_locked org.gtk.Property.set=adw_flap_set_locked)
@@ -1436,12 +1461,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * unfolding it when the flap is not revealed opens it. If `TRUE`,
    * [property@Flap:reveal-flap] value never changes on its own.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_LOCKED] =
-    g_param_spec_boolean ("locked", NULL, NULL,
+    g_param_spec_boolean ("locked",
+                          "Locked",
+                          "Whether the flap is locked",
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:transition-type: (attributes org.gtk.Property.get=adw_flap_get_transition_type org.gtk.Property.set=adw_flap_set_transition_type)
@@ -1453,13 +1480,15 @@ adw_flap_class_init (AdwFlapClass *klass)
    * add the [`.background`](style-classes.html#background) style class to it if
    * this is unwanted.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_TRANSITION_TYPE] =
-    g_param_spec_enum ("transition-type", NULL, NULL,
+    g_param_spec_enum ("transition-type",
+                       "Transition Type",
+                       "The type of animation used for reveal and fold transitions",
                        ADW_TYPE_FLAP_TRANSITION_TYPE,
                        ADW_FLAP_TRANSITION_TYPE_OVER,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:modal: (attributes org.gtk.Property.get=adw_flap_get_modal org.gtk.Property.set=adw_flap_set_modal)
@@ -1470,12 +1499,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks
    * are passed through to the content widget.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_MODAL] =
-    g_param_spec_boolean ("modal", NULL, NULL,
+    g_param_spec_boolean ("modal",
+                          "Modal",
+                          "Whether the flap is modal",
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:swipe-to-open: (attributes org.gtk.Property.get=adw_flap_get_swipe_to_open org.gtk.Property.set=adw_flap_set_swipe_to_open)
@@ -1485,12 +1516,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * The area that can be swiped depends on the [property@Flap:transition-type]
    * value.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_SWIPE_TO_OPEN] =
-    g_param_spec_boolean ("swipe-to-open", NULL, NULL,
+    g_param_spec_boolean ("swipe-to-open",
+                          "Swipe to Open",
+                          "Whether the flap can be opened with a swipe gesture",
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:swipe-to-close: (attributes org.gtk.Property.get=adw_flap_get_swipe_to_close org.gtk.Property.set=adw_flap_set_swipe_to_close)
@@ -1500,12 +1533,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    * The area that can be swiped depends on the [property@Flap:transition-type]
    * value.
    *
-   * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+   * Since: 1.0
    */
   props[PROP_SWIPE_TO_CLOSE] =
-    g_param_spec_boolean ("swipe-to-close", NULL, NULL,
+    g_param_spec_boolean ("swipe-to-close",
+                          "Swipe to Close",
+                          "Whether the flap can be closed with a swipe gesture",
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -1519,10 +1554,7 @@ adw_flap_class_init (AdwFlapClass *klass)
 static gboolean
 flap_close_cb (AdwFlap *self)
 {
-  if (G_APPROX_VALUE (self->reveal_progress, 0, DBL_EPSILON) ||
-      self->reveal_progress < 0 ||
-      G_APPROX_VALUE (self->fold_progress, 0, DBL_EPSILON) ||
-      self->fold_progress < 0)
+  if (self->reveal_progress <= 0 || self->fold_progress <= 0)
     return GDK_EVENT_PROPAGATE;
 
   adw_flap_set_reveal_flap (ADW_FLAP (self), FALSE);
@@ -1533,6 +1565,7 @@ flap_close_cb (AdwFlap *self)
 static void
 adw_flap_init (AdwFlap *self)
 {
+  GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET (self));
   GtkEventController *gesture;
   GtkShortcut *shortcut;
   AdwAnimationTarget *target;
@@ -1582,7 +1615,7 @@ adw_flap_init (AdwFlap *self)
 
   gtk_widget_set_overflow (GTK_WIDGET (self), GTK_OVERFLOW_HIDDEN);
 
-  gtk_widget_add_css_class (GTK_WIDGET (self), "unfolded");
+  gtk_style_context_add_class (context, "unfolded");
 
   target = adw_callback_animation_target_new ((AdwAnimationTargetFunc)
                                               fold_animation_value_cb,
@@ -1734,8 +1767,7 @@ adw_flap_get_swipe_area (AdwSwipeable           *swipeable,
   content_factor = transition_get_content_motion_factor (self);
 
   if (!is_drag ||
-      ((G_APPROX_VALUE (flap_factor, 1, DBL_EPSILON) || flap_factor > 1) &&
-       (G_APPROX_VALUE (content_factor, 1, DBL_EPSILON) || content_factor > 1)) ||
+      (flap_factor >= 1 && content_factor >= 1) ||
       (self->fold_progress < 1 && flap_factor > 0)) {
     rect->x = 0;
     rect->y = 0;
@@ -1795,7 +1827,7 @@ adw_flap_swipeable_init (AdwSwipeableInterface *iface)
  *
  * Returns: the newly created `AdwFlap`
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 GtkWidget *
 adw_flap_new (void)
@@ -1811,7 +1843,7 @@ adw_flap_new (void)
  *
  * Returns: (transfer none) (nullable): the content widget for @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 GtkWidget *
 adw_flap_get_content (AdwFlap *self)
@@ -1828,9 +1860,7 @@ adw_flap_get_content (AdwFlap *self)
  *
  * Sets the content widget for @self.
  *
- * It's always displayed when unfolded, and partially visible when folded.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_content (AdwFlap   *self,
@@ -1839,9 +1869,6 @@ adw_flap_set_content (AdwFlap   *self,
   g_return_if_fail (ADW_IS_FLAP (self));
   g_return_if_fail (content == NULL || GTK_IS_WIDGET (content));
 
-  if (content)
-    g_return_if_fail (gtk_widget_get_parent (content) == NULL);
-
   if (self->content.widget == content)
     return;
 
@@ -1866,7 +1893,7 @@ adw_flap_set_content (AdwFlap   *self,
  *
  * Returns: (transfer none) (nullable): the flap widget for @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 GtkWidget *
 adw_flap_get_flap (AdwFlap *self)
@@ -1883,9 +1910,7 @@ adw_flap_get_flap (AdwFlap *self)
  *
  * Sets the flap widget for @self.
  *
- * It's only visible when [property@Flap:reveal-progress] is greater than 0.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_flap (AdwFlap   *self,
@@ -1894,9 +1919,6 @@ adw_flap_set_flap (AdwFlap   *self,
   g_return_if_fail (ADW_IS_FLAP (self));
   g_return_if_fail (flap == NULL || GTK_IS_WIDGET (flap));
 
-  if (flap)
-    g_return_if_fail (gtk_widget_get_parent (flap) == NULL);
-
   if (self->flap.widget == flap)
     return;
 
@@ -1922,7 +1944,7 @@ adw_flap_set_flap (AdwFlap   *self,
  *
  * Returns: (transfer none) (nullable): the separator widget for @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 GtkWidget *
 adw_flap_get_separator (AdwFlap *self)
@@ -1939,11 +1961,7 @@ adw_flap_get_separator (AdwFlap *self)
  *
  * Sets the separator widget for @self.
  *
- * It's displayed between content and flap when there's no shadow to display.
- * When exactly it's visible depends on the [property@Flap:transition-type]
- * value.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_separator (AdwFlap   *self,
@@ -1952,9 +1970,6 @@ adw_flap_set_separator (AdwFlap   *self,
   g_return_if_fail (ADW_IS_FLAP (self));
   g_return_if_fail (separator == NULL || GTK_IS_WIDGET (separator));
 
-  if (separator)
-    g_return_if_fail (gtk_widget_get_parent (separator) == NULL);
-
   if (self->separator.widget == separator)
     return;
 
@@ -1979,7 +1994,7 @@ adw_flap_set_separator (AdwFlap   *self,
  *
  * Returns: the flap position for @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 GtkPackType
 adw_flap_get_flap_position (AdwFlap *self)
@@ -1996,10 +2011,7 @@ adw_flap_get_flap_position (AdwFlap *self)
  *
  * Sets the flap position for @self.
  *
- * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
- * if `GTK_PACK_END`, it's displayed after the content.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_flap_position (AdwFlap     *self,
@@ -2027,7 +2039,7 @@ adw_flap_set_flap_position (AdwFlap     *self,
  *
  * Returns: `TRUE` if the flap widget is revealed
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 gboolean
 adw_flap_get_reveal_flap (AdwFlap *self)
@@ -2044,7 +2056,7 @@ adw_flap_get_reveal_flap (AdwFlap *self)
  *
  * Sets whether the flap widget is revealed for @self.
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_reveal_flap (AdwFlap  *self,
@@ -2063,7 +2075,7 @@ adw_flap_set_reveal_flap (AdwFlap  *self,
  *
  * Returns: the reveal animation parameters
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 AdwSpringParams *
 adw_flap_get_reveal_params (AdwFlap *self)
@@ -2080,13 +2092,7 @@ adw_flap_get_reveal_params (AdwFlap *self)
  *
  * Sets the reveal animation spring parameters for @self.
  *
- * The default value is equivalent to:
- *
- * ```c
- * adw_spring_params_new (1, 0.5, 500)
- * ```
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_reveal_params (AdwFlap         *self,
@@ -2110,13 +2116,9 @@ adw_flap_set_reveal_params (AdwFlap         *self,
  *
  * Gets the current reveal progress for @self.
  *
- * 0 means fully hidden, 1 means fully revealed.
- *
- * See [property@Flap:reveal-flap].
- *
  * Returns: the current reveal progress for @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 double
 adw_flap_get_reveal_progress (AdwFlap *self)
@@ -2134,7 +2136,7 @@ adw_flap_get_reveal_progress (AdwFlap *self)
  *
  * Returns: the fold policy for @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 AdwFlapFoldPolicy
 adw_flap_get_fold_policy (AdwFlap *self)
@@ -2151,7 +2153,7 @@ adw_flap_get_fold_policy (AdwFlap *self)
  *
  * Sets the fold policy for @self.
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_fold_policy (AdwFlap           *self,
@@ -2185,64 +2187,15 @@ adw_flap_set_fold_policy (AdwFlap           *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLD_POLICY]);
 }
 
-/**
- * adw_flap_get_fold_threshold_policy: (attributes org.gtk.Method.get_property=fold-threshold-policy)
- * @self: a flap
- *
- * Gets the fold threshold policy for @self.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
- */
-AdwFoldThresholdPolicy
-adw_flap_get_fold_threshold_policy (AdwFlap *self)
-{
-  g_return_val_if_fail (ADW_IS_FLAP (self), ADW_FOLD_THRESHOLD_POLICY_MINIMUM);
-
-  return self->fold_threshold_policy;
-}
-
-/**
- * adw_flap_set_fold_threshold_policy: (attributes org.gtk.Method.set_property=fold-threshold-policy)
- * @self: a flap
- * @policy: the policy to use
- *
- * Sets the fold threshold policy for @self.
- *
- * If set to `ADW_FOLD_THRESHOLD_POLICY_MINIMUM`, flap will only fold when the
- * children cannot fit anymore. With `ADW_FOLD_THRESHOLD_POLICY_NATURAL`, it
- * will fold as soon as children don't get their natural size.
- *
- * This can be useful if you have a long ellipsizing label and want to let it
- * ellipsize instead of immediately folding.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
- */
-void
-adw_flap_set_fold_threshold_policy (AdwFlap                *self,
-                                    AdwFoldThresholdPolicy  policy)
-{
-  g_return_if_fail (ADW_IS_FLAP (self));
-  g_return_if_fail (policy <= ADW_FOLD_THRESHOLD_POLICY_NATURAL);
-
-  if (self->fold_threshold_policy == policy)
-    return;
-
-  self->fold_threshold_policy = policy;
-
-  gtk_widget_queue_allocate (GTK_WIDGET (self));
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLD_THRESHOLD_POLICY]);
-}
-
 /**
  * adw_flap_get_fold_duration: (attributes org.gtk.Method.get_property=fold-duration)
  * @self: a flap
  *
- * Gets the fold transition animation duration for @self, in milliseconds.
+ * Gets the duration that fold transitions in @self will take.
  *
  * Returns: the fold transition duration
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 guint
 adw_flap_get_fold_duration (AdwFlap *self)
@@ -2257,9 +2210,9 @@ adw_flap_get_fold_duration (AdwFlap *self)
  * @self: a flap
  * @duration: the new duration, in milliseconds
  *
- * Sets the fold transition animation duration for @self, in milliseconds.
+ * Sets the duration that fold transitions in @self will take.
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_fold_duration (AdwFlap *self,
@@ -2281,11 +2234,9 @@ adw_flap_set_fold_duration (AdwFlap *self,
  *
  * Gets whether @self is currently folded.
  *
- * See [property@Flap:fold-policy].
- *
  * Returns: `TRUE` if @self is currently folded
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 gboolean
 adw_flap_get_folded (AdwFlap *self)
@@ -2303,7 +2254,7 @@ adw_flap_get_folded (AdwFlap *self)
  *
  * Returns: `TRUE` if @self is locked
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 gboolean
 adw_flap_get_locked (AdwFlap *self)
@@ -2320,11 +2271,7 @@ adw_flap_get_locked (AdwFlap *self)
  *
  * Sets whether @self is locked.
  *
- * If `FALSE`, folding when the flap is revealed automatically closes it, and
- * unfolding it when the flap is not revealed opens it. If `TRUE`,
- * [property@Flap:reveal-flap] value never changes on its own.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_locked (AdwFlap  *self,
@@ -2350,7 +2297,7 @@ adw_flap_set_locked (AdwFlap  *self,
  *
  * Returns: the current transition type of @self
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 AdwFlapTransitionType
 adw_flap_get_transition_type (AdwFlap *self)
@@ -2367,12 +2314,7 @@ adw_flap_get_transition_type (AdwFlap *self)
  *
  * Sets the type of animation used for reveal and fold transitions in @self.
  *
- * [property@Flap:flap] is transparent by default, which means the content will
- * be seen through it with `ADW_FLAP_TRANSITION_TYPE_OVER` transitions; add the
- * [`.background`](style-classes.html#background) style class to it if this is
- * unwanted.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_transition_type (AdwFlap               *self,
@@ -2402,7 +2344,7 @@ adw_flap_set_transition_type (AdwFlap               *self,
  *
  * Returns: `TRUE` if @self is modal
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 gboolean
 adw_flap_get_modal (AdwFlap *self)
@@ -2419,11 +2361,7 @@ adw_flap_get_modal (AdwFlap *self)
  *
  * Sets whether @self is modal.
  *
- * If `TRUE`, clicking the content widget while flap is revealed, as well as
- * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks are
- * passed through to the content widget.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_modal (AdwFlap  *self,
@@ -2454,7 +2392,7 @@ adw_flap_set_modal (AdwFlap  *self,
  *
  * Returns: `TRUE` if @self can be opened with a swipe gesture
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 gboolean
 adw_flap_get_swipe_to_open (AdwFlap *self)
@@ -2471,10 +2409,7 @@ adw_flap_get_swipe_to_open (AdwFlap *self)
  *
  * Sets whether @self can be opened with a swipe gesture.
  *
- * The area that can be swiped depends on the [property@Flap:transition-type]
- * value.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_swipe_to_open (AdwFlap  *self,
@@ -2502,7 +2437,7 @@ adw_flap_set_swipe_to_open (AdwFlap  *self,
  *
  * Returns: `TRUE` if @self can be closed with a swipe gesture
  *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 gboolean
 adw_flap_get_swipe_to_close (AdwFlap *self)
@@ -2519,10 +2454,7 @@ adw_flap_get_swipe_to_close (AdwFlap *self)
  *
  * Sets whether @self can be closed with a swipe gesture.
  *
- * The area that can be swiped depends on the [property@Flap:transition-type]
- * value.
- *
- * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwflap)
+ * Since: 1.0
  */
 void
 adw_flap_set_swipe_to_close (AdwFlap  *self,
@@ -2541,3 +2473,45 @@ adw_flap_set_swipe_to_close (AdwFlap  *self,
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SWIPE_TO_CLOSE]);
 }
+
+/**
+ * adw_flap_get_fold_threshold_policy: (attributes org.gtk.Method.get_property=fold-threshold-policy)
+ * @self: a flap
+ *
+ * Gets the fold threshold policy for @self.
+ *
+ * Since: 1.0
+ */
+AdwFoldThresholdPolicy
+adw_flap_get_fold_threshold_policy (AdwFlap *self)
+{
+  g_return_val_if_fail (ADW_IS_FLAP (self), ADW_FOLD_THRESHOLD_POLICY_MINIMUM);
+
+  return self->fold_threshold_policy;
+}
+
+/**
+ * adw_flap_set_fold_threshold_policy: (attributes org.gtk.Method.set_property=fold-threshold-policy)
+ * @self: a flap
+ * @policy: the policy to use
+ *
+ * Sets the fold threshold policy for @self.
+ *
+ * Since: 1.0
+ */
+void
+adw_flap_set_fold_threshold_policy (AdwFlap                *self,
+                                    AdwFoldThresholdPolicy  policy)
+{
+  g_return_if_fail (ADW_IS_FLAP (self));
+  g_return_if_fail (policy <= ADW_FOLD_THRESHOLD_POLICY_NATURAL);
+
+  if (self->fold_threshold_policy == policy)
+    return;
+
+  self->fold_threshold_policy = policy;
+
+  gtk_widget_queue_allocate (GTK_WIDGET (self));
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLD_THRESHOLD_POLICY]);
+}
