@@ -8,6 +8,7 @@
 #include "config.h"
 
 #include "adw-indicator-bin-private.h"
+#include "adw-macros-private.h"
 #include "adw-view-switcher-button-private.h"
 
 #define TIMEOUT_EXPAND 500
@@ -54,12 +55,14 @@ static GParamSpec *props[LAST_PROP];
 G_DEFINE_FINAL_TYPE_WITH_CODE (AdwViewSwitcherButton, adw_view_switcher_button, GTK_TYPE_TOGGLE_BUTTON,
                                G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL))
 
-static void
-switch_timeout_cb (AdwViewSwitcherButton *self)
+static gboolean
+adw_view_switcher_button_switch_timeout (AdwViewSwitcherButton *self)
 {
   self->switch_timer = 0;
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self), TRUE);
+
+  return G_SOURCE_REMOVE;
 }
 
 static void
@@ -81,11 +84,10 @@ drag_enter_cb (AdwViewSwitcherButton *self)
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self)))
     return;
 
-  self->switch_timer =
-    g_timeout_add_once (TIMEOUT_EXPAND,
-                        (GSourceOnceFunc) switch_timeout_cb,
-                        self);
-  g_source_set_name_by_id (self->switch_timer, "[adw] switch_timeout_cb");
+  self->switch_timer = g_timeout_add (TIMEOUT_EXPAND,
+                                      (GSourceFunc) adw_view_switcher_button_switch_timeout,
+                                      self);
+  g_source_set_name_by_id (self->switch_timer, "[gtk] adw_view_switcher_switch_timeout");
 }
 
 static void
@@ -275,11 +277,15 @@ adw_view_switcher_button_class_init (AdwViewSwitcherButtonClass *klass)
    * AdwViewSwitcherButton:icon-name: (attributes org.gtk.Property.get=adw_view_switcher_button_get_icon_name org.gtk.Property.set=adw_view_switcher_button_set_icon_name)
    *
    * The icon name representing the view, or `NULL` for no icon.
+   *
+   * Since: 1.0
    */
   props[PROP_ICON_NAME] =
-    g_param_spec_string ("icon-name", NULL, NULL,
+    g_param_spec_string ("icon-name",
+                         "Icon Name",
+                         "Icon name for image",
                          "text-x-generic-symbolic",
-                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE);
 
   /**
    * AdwViewSwitcherButton:needs-attention: (attributes org.gtk.Property.get=adw_view_switcher_button_get_needs_attention org.gtk.Property.set=adw_view_switcher_button_set_needs_attention)
@@ -289,23 +295,31 @@ adw_view_switcher_button_class_init (AdwViewSwitcherButtonClass *klass)
    * This is used by the [class@ViewSwitcher] to change the appearance of the
    * corresponding button when a view needs attention and it is not the current
    * one.
+   *
+   * Since: 1.0
    */
   props[PROP_NEEDS_ATTENTION] =
-    g_param_spec_boolean ("needs-attention", NULL, NULL,
+    g_param_spec_boolean ("needs-attention",
+                          "Needs attention",
+                          "Hint the view needs attention",
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE);
 
   /**
    * AdwViewSwitcherButton:badge-number:
    *
    * A number to display as a badge on the button.
+   *
+   * Since: 1.0
    */
   props[PROP_BADGE_NUMBER] =
-    g_param_spec_uint ("badge-number", NULL, NULL,
+    g_param_spec_uint ("badge-number",
+                       "Badge number",
+                       "A number to display as a badge on the button",
                        0,
                        G_MAXUINT,
                        0,
-                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -355,6 +369,8 @@ adw_view_switcher_button_init (AdwViewSwitcherButton *self)
  * Creates a new `AdwViewSwitcherButton`.
  *
  * Returns: the newly created `AdwViewSwitcherButton`
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_view_switcher_button_new (void)
@@ -369,6 +385,8 @@ adw_view_switcher_button_new (void)
  * Gets the icon name representing the view.
  *
  * Returns: (nullable): the icon name
+ *
+ * Since: 1.0
  **/
 const char *
 adw_view_switcher_button_get_icon_name (AdwViewSwitcherButton *self)
@@ -384,6 +402,8 @@ adw_view_switcher_button_get_icon_name (AdwViewSwitcherButton *self)
  * @icon_name: (nullable): an icon name
  *
  * Sets the icon name representing the view.
+ *
+ * Since: 1.0
  **/
 void
 adw_view_switcher_button_set_icon_name (AdwViewSwitcherButton *self,
@@ -394,10 +414,12 @@ adw_view_switcher_button_set_icon_name (AdwViewSwitcherButton *self,
   if (!g_strcmp0 (self->icon_name, icon_name))
     return;
 
-  if (icon_name && *icon_name)
-    g_set_str (&self->icon_name, icon_name);
+  g_free (self->icon_name);
+
+  if (icon_name && strlen (icon_name) > 0)
+    self->icon_name = g_strdup (icon_name);
   else
-    g_set_str (&self->icon_name, "image-missing");
+    self->icon_name = g_strdup ("image-missing");
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ICON_NAME]);
 }
@@ -409,6 +431,8 @@ adw_view_switcher_button_set_icon_name (AdwViewSwitcherButton *self,
  * Gets whether the view represented by @self requires the user attention.
  *
  * Returns: whether the view requires the user attention
+ *
+ * Since: 1.0
  **/
 gboolean
 adw_view_switcher_button_get_needs_attention (AdwViewSwitcherButton *self)
@@ -424,6 +448,8 @@ adw_view_switcher_button_get_needs_attention (AdwViewSwitcherButton *self)
  * @needs_attention: whether the view needs attention
  *
  * Sets whether the view represented by @self requires the user attention.
+ *
+ * Since: 1.0
  */
 void
 adw_view_switcher_button_set_needs_attention (AdwViewSwitcherButton *self,
@@ -448,6 +474,8 @@ adw_view_switcher_button_set_needs_attention (AdwViewSwitcherButton *self,
  * Gets the badge number.
  *
  * Returns: the badge number
+ *
+ * Since: 1.0
  */
 guint
 adw_view_switcher_button_get_badge_number (AdwViewSwitcherButton *self)
@@ -463,6 +491,8 @@ adw_view_switcher_button_get_badge_number (AdwViewSwitcherButton *self)
  * @badge_number: the new value
  *
  * Sets the badge number.
+ *
+ * Since: 1.0
  */
 void
 adw_view_switcher_button_set_badge_number (AdwViewSwitcherButton *self,
@@ -485,6 +515,8 @@ adw_view_switcher_button_set_badge_number (AdwViewSwitcherButton *self,
  * Gets the label representing the view.
  *
  * Returns: (nullable): the label
+ *
+ * Since: 1.0
  **/
 const char *
 adw_view_switcher_button_get_label (AdwViewSwitcherButton *self)
@@ -500,6 +532,8 @@ adw_view_switcher_button_get_label (AdwViewSwitcherButton *self)
  * @label: (nullable): a label
  *
  * Sets the label representing the view.
+ *
+ * Since: 1.0
  **/
 void
 adw_view_switcher_button_set_label (AdwViewSwitcherButton *self,
@@ -507,8 +541,11 @@ adw_view_switcher_button_set_label (AdwViewSwitcherButton *self,
 {
   g_return_if_fail (ADW_IS_VIEW_SWITCHER_BUTTON (self));
 
-  if (!g_set_str (&self->label, label))
+  if (!g_strcmp0 (self->label, label))
     return;
 
+  g_free (self->label);
+  self->label = g_strdup (label);
+
   g_object_notify (G_OBJECT (self), "label");
 }
